==> breeze_website_builder_5.4.55.tar.gz: manage/change_password.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised:	12/9/2010	ELL
// Added password feedback in message.
// Revised: 2/7/2012	ELL
// Added table prefix handling.
// Revised: 7/2/2012	ELL
// Adapted for website user page restrictions as well.
// Added insertion of salt into password before encrypting.
//
	include ("check_session.php");

	$user_name = $_POST['user_name'];
	$password = $_POST['password'];
	$table = $_POST['table'];
	
	if ($table == "-not selected-")
	{
		echo "You must select a table first to change the password of a user.  Click <a href=\"manage_page_access.php\" title=\"here\">here</a> to select a table and try again.";
		exit;
	}
	
	// Insert salt into password.
	$pos = rand(0, (strlen($password)-1) );
	$pass1 = substr($password, 0, $pos);
	$pass2 = substr($password, $pos);
	if ($_POST['website_user'] == 1)
		$salted_pass = $pass1 . BWB_PUB_SALT . $pass2;
	else
		$salted_pass = $pass1 . BWB_SALT . $pass2;
	//Encrypt password using user name as key.
	$encrypt_password = doEncrypt($salted_pass, $user_name);

	// Change password.
	if ((!$table) || ($table == ""))
		$query = "UPDATE `" . BWB_TABLE_PREFIX . "users` SET `password`='$encrypt_password' WHERE `UserID`='$user_name'";
	else
		$query = "UPDATE `" . $table . "` SET `password`='$encrypt_password' WHERE `UserID`='$user_name'";
		
	$cnt = $bwb_dbh->exec($query);
	
	$_SESSION['last_user'] = $user_name;
	
	echo "user_name=$user_name@@@@@password=$password";
	
	exit;
/////////////////////////////////
function doEncrypt($Data, $Key)
{
// encrypting  a[] with key k[] into e[]
// a[] = array to be encrypted
// k[] = key of truly random gibberish
// e[] = encrypted data

	for( $i = 0; $i < strlen($Data); $i++)
	{
		$c = substr($Data, $i, 1);
		$a[$i] = ord($c);
	}
	
	for( $i = 0; $i < strlen($Data); $i++)
	{
		if ($i < strlen($Key))
		{
			$c = substr($Key, $i, 1);
			$k[$i] = ord($c);
		}
		else
			$k[$i] = 65 + $i;
	}
	
	for ( $i=0; $i < strlen($Data); $i++ )
   	{
   		$e[$i] = $k[$i] ^ $a[$i];
   	}
	
	$encrypted = "";
	for ( $i = 0; $i < strlen($Data); $i++ )
	{
		$encrypted = $encrypted. decToHex($e[$i]);
	}
	return($encrypted);
	
}

function decToHex($dec)
{
	$hexStr = "0123456789ABCDEF";
	$low = $dec % 16;
	$high = ($dec - $low)/16;
	$hex = "";
	$hex = substr($hexStr, $high, 1) . substr($hexStr, $low, 1);
	return $hex;
}
?>

==> breeze_website_builder_6.1.20.tar.gz: manage/change_password.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised:	12/9/2010	ELL
// Added password feedback in message.
// Revised: 2/7/2012	ELL
// Added table prefix handling.
// Revised: 7/2/2012	ELL
// Adapted for website user page restrictions as well.
// Added insertion of salt into password before encrypting.
//
	include ("check_session.php");

	$user_name = $_POST['user_name'];
	$password = $_POST['password'];
	$table = $_POST['table'];
	$no_prefix = $_REQUEST['no_prefix'];
	
	if (!isset($table) || ($table == "-not selected-") || ($table == ""))
	{
		echo MANAGE_USERS_NO_TABLE_TO_CHANGE_USER_PASSWORD_ERR . " " . CLICK_WORD . " <a href=\"manage_page_access.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . MANAGE_USERS_NO_TABLE_TO_ADD_USER_TO_2_ERR;
		exit;
	}
	
	// Insert salt into password.
	$pos = rand(0, (strlen($password)-1) );
	$pass1 = substr($password, 0, $pos);
	$pass2 = substr($password, $pos);
	if ($_POST['website_user'] == 1)
		$salted_pass = $pass1 . BWB_PUB_SALT . $pass2;
	else
		$salted_pass = $pass1 . BWB_SALT . $pass2;
	//Encrypt password using user name as key.
	$encrypt_password = doEncrypt($salted_pass, $user_name);
	
	if (isset($no_prefix) && ($no_prefix == 1))
		$prefix = "";
	else
		$prefix = BWB_TABLE_PREFIX;

	// Change password.
	$query = "UPDATE `" . $prefix . $table . "` SET `password`='$encrypt_password' WHERE `UserID`='$user_name'";
		
	$cnt = $bwb_dbh->exec($query);
	
	$_SESSION['last_user'] = $user_name;
	
	echo "user_name=$user_name@@@@@password=$password";
	
	exit;
/////////////////////////////////
function doEncrypt($Data, $Key)
{
// encrypting  a[] with key k[] into e[]
// a[] = array to be encrypted
// k[] = key of truly random gibberish
// e[] = encrypted data

	for( $i = 0; $i < strlen($Data); $i++)
	{
		$c = substr($Data, $i, 1);
		$a[$i] = ord($c);
	}
	
	for( $i = 0; $i < strlen($Data); $i++)
	{
		if ($i < strlen($Key))
		{
			$c = substr($Key, $i, 1);
			$k[$i] = ord($c);
		}
		else
			$k[$i] = 65 + $i;
	}
	
	for ( $i=0; $i < strlen($Data); $i++ )
   	{
   		$e[$i] = $k[$i] ^ $a[$i];
   	}
	
	$encrypted = "";
	for ( $i = 0; $i < strlen($Data); $i++ )
	{
		$encrypted = $encrypted. decToHex($e[$i]);
	}
	return($encrypted);
	
}

function decToHex($dec)
{
	$hexStr = "0123456789ABCDEF";
	$low = $dec % 16;
	$high = ($dec - $low)/16;
	$hex = "";
	$hex = substr($hexStr, $high, 1) . substr($hexStr, $low, 1);
	return $hex;
}
?>
